@@ -236,8 +236,8 @@ from math import sqrt, log  # Optimization: no attribute look-up
 import copy
 
 # Numerical version:
-__version_info__ = (1, 7, 2)
-__version__ = '.'.join(str(num) for num in __version_info__)
+__version_info__ = (1, 7, 3)
+__version__ = '.'.join([str(num) for num in __version_info__])
 
 __author__ = 'Eric O. LEBIGOT (EOL)'
 
@@ -1440,6 +1440,7 @@ def ufloat(representation, tag=None):
         1234567(1.2)
         12.345(15)
         -12.3456(78)e-6
+        12.3(0.4)e-5        
         0.29
         31.
         -31.
